@@ -128,7 +128,7 @@ class DaemonApplication(object):
             daemon_start(self.main, pidfile=pidfile, daemon=daemon, workspace=workspace)
 
         @main.command()
-        def stop(sig):
+        def stop():
             """Stop daemon application.
             """
             pidfile = self.config["pidfile"]
